@@ -5,7 +5,8 @@ from .tuanfuncs import F_test
 from .tuanfuncs import rsquares_iter
 from .tuanfuncs import quick_rf_importance
 from .tuanfuncs import permutation_importance
-from .tuanfuncs import woe_iv
+from .tuanfuncs import woe_iv_continuous
+from .tuanfuncs import woe_iv_categ
 from .tuanfuncs import barchart_dict
 
 
