@@ -115,7 +115,7 @@ def permutation_importance(my_model,val_X, val_y):
     perm = PermutationImportance(my_model, random_state=1).fit(val_X, val_y)
     eli5.show_weights(perm, feature_names = val_X.columns.tolist())
 
-def woe_iv(X,y,regularize:str):
+def woe_iv_continuous(X,y,regularize:str):
     """
     Finding weight of importance and informational value for binary classification tasks
     """
@@ -162,3 +162,50 @@ def woe_iv(X,y,regularize:str):
     return woe_dict, IV_dict
 
 
+def woe_iv_categ(X,y,regularize:str):
+    """
+    Finding weight of importance and informational value for binary classification tasks
+    """
+    df = X.copy()
+    df['target'] = y.copy()
+    IV_dict = {}
+    woe_dict = {}
+
+    for col in X.columns:
+        # binning values
+        bins = np.linspace(df[col].min()-0.1, df[col].max()+0.1, len(set(df[col])))  # each bin should have at least 5% of the observation
+        groups = df.groupby(np.digitize(df[col], bins))
+        df[col] = pd.cut(df[col], bins)
+
+        # getting class counts for each bin
+        count_series = df.groupby([col, 'target']).size()
+        new_df = count_series.to_frame(name = 'size').reset_index()
+        if regularize == True:
+            new_df['size'] = new_df['size'] + 0.5
+        df1  = new_df[new_df['target']==0].reset_index(drop=True)
+        df2  = new_df[new_df['target']==1].reset_index(drop=True)
+        df1['size1'] = df2['size']
+        new_df = df1.drop(columns=['target'])
+        sum = new_df['size'].sum()
+        sum1 = new_df['size1'].sum()
+        # Calculate woe and IV
+        new_df['woe'] = np.log((new_df['size']/sum)/(new_df['size1']/sum1))
+        new_df['IV'] = ((new_df['size']/sum) - (new_df['size1']/sum1)) * new_df['woe']
+        new_df = new_df.replace([np.inf, -np.inf], np.nan)
+        new_df.dropna(inplace=True)
+        woe_dict[col] = new_df.drop(columns=['size','size1'])
+        IV_dict[col] = new_df['IV'].sum()
+
+        # df_woe_iv = (pd.crosstab(df[col],df['target'],
+        #                   normalize='columns')
+        #          .assign(woe=lambda dfx: np.log(dfx[1] / dfx[0]))
+        #          .assign(iv=lambda dfx: np.sum(dfx['woe']*
+        #                                        (dfx[1]-dfx[0]))))
+        # df_woe_iv = df_woe_iv.replace([np.inf, -np.inf], np.nan)
+        # df_woe_iv.dropna(inplace=True)
+        # woe_dict[col] = df_woe_iv
+        # IV_dict[col] = df_woe_iv['iv'].sum()
+
+    return woe_dict, IV_dict
+
+
